/*
*  Copyright 2019-2020 Zheng Jie
*
*  Licensed under the Apache License, Version 2.0 (the "License");
*  you may not use this file except in compliance with the License.
*  You may obtain a copy of the License at
*
*  http://www.apache.org/licenses/LICENSE-2.0
*
*  Unless required by applicable law or agreed to in writing, software
*  distributed under the License is distributed on an "AS IS" BASIS,
*  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
*  See the License for the specific language governing permissions and
*  limitations under the License.
*/
package me.zhengjie.modules.dm.envmonitor.historydata.service.impl;

import me.zhengjie.modules.dm.envmonitor.historydata.domain.DmEnvHistoryData;
import me.zhengjie.utils.ValidationUtil;
import me.zhengjie.utils.FileUtil;
import lombok.RequiredArgsConstructor;
import me.zhengjie.modules.dm.envmonitor.historydata.repository.DmEnvHistoryDataRepository;
import me.zhengjie.modules.dm.envmonitor.historydata.service.DmEnvHistoryDataService;
import me.zhengjie.modules.dm.envmonitor.historydata.service.dto.DmEnvHistoryDataDto;
import me.zhengjie.modules.dm.envmonitor.historydata.service.dto.DmEnvHistoryDataQueryCriteria;
import me.zhengjie.modules.dm.envmonitor.historydata.service.mapstruct.DmEnvHistoryDataMapper;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import me.zhengjie.utils.PageUtil;
import me.zhengjie.utils.QueryHelp;
import java.util.List;
import java.util.Map;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import java.util.ArrayList;
import java.util.LinkedHashMap;

/**
* @website https://el-admin.vip
* @description 服务实现
* @author lr
* @date 2022-05-19
**/
@Service
@RequiredArgsConstructor
public class DmEnvHistoryDataServiceImpl implements DmEnvHistoryDataService {

    private final DmEnvHistoryDataRepository dmEnvHistoryDataRepository;
    private final DmEnvHistoryDataMapper dmEnvHistoryDataMapper;

    @Override
    public Map<String,Object> queryAll(DmEnvHistoryDataQueryCriteria criteria, Pageable pageable){
        Page<DmEnvHistoryData> page = dmEnvHistoryDataRepository.findAll((root, criteriaQuery, criteriaBuilder) -> QueryHelp.getPredicate(root,criteria,criteriaBuilder),pageable);
        return PageUtil.toPage(page.map(dmEnvHistoryDataMapper::toDto));
    }

    @Override
    public List<DmEnvHistoryDataDto> queryAll(DmEnvHistoryDataQueryCriteria criteria){
        return dmEnvHistoryDataMapper.toDto(dmEnvHistoryDataRepository.findAll((root, criteriaQuery, criteriaBuilder) -> QueryHelp.getPredicate(root,criteria,criteriaBuilder)));
    }

    @Override
    @Transactional
    public DmEnvHistoryDataDto findById(Long id) {
        DmEnvHistoryData dmEnvHistoryData = dmEnvHistoryDataRepository.findById(id).orElseGet(DmEnvHistoryData::new);
        ValidationUtil.isNull(dmEnvHistoryData.getId(),"DmEnvHistoryData","id",id);
        return dmEnvHistoryDataMapper.toDto(dmEnvHistoryData);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public DmEnvHistoryDataDto create(DmEnvHistoryData resources) {
        return dmEnvHistoryDataMapper.toDto(dmEnvHistoryDataRepository.save(resources));
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public void update(DmEnvHistoryData resources) {
        DmEnvHistoryData dmEnvHistoryData = dmEnvHistoryDataRepository.findById(resources.getId()).orElseGet(DmEnvHistoryData::new);
        ValidationUtil.isNull( dmEnvHistoryData.getId(),"DmEnvHistoryData","id",resources.getId());
        dmEnvHistoryData.copy(resources);
        dmEnvHistoryDataRepository.save(dmEnvHistoryData);
    }

    @Override
    public void deleteAll(Long[] ids) {
        for (Long id : ids) {
            dmEnvHistoryDataRepository.deleteById(id);
        }
    }

    @Override
    public void download(List<DmEnvHistoryDataDto> all, HttpServletResponse response) throws IOException {
        List<Map<String, Object>> list = new ArrayList<>();
        for (DmEnvHistoryDataDto dmEnvHistoryData : all) {
            Map<String,Object> map = new LinkedHashMap<>();
            map.put("设备编号", dmEnvHistoryData.getDeviceIdentifier());
            map.put("设备名称", dmEnvHistoryData.getDeviceName());
            map.put("监控对象", dmEnvHistoryData.getMonitorObject());
            map.put("创建人", dmEnvHistoryData.getCreateBy());
            map.put("更新人", dmEnvHistoryData.getUpdateBy());
            map.put("创建时间", dmEnvHistoryData.getCreateTime());
            map.put("更新时间", dmEnvHistoryData.getUpdateTime());
            map.put("状态 0离线 1在线 2告警", dmEnvHistoryData.getDeviceState());
            list.add(map);
        }
        FileUtil.downloadExcel(list, response);
    }
}