/*
*  Copyright 2019-2020 Zheng Jie
*
*  Licensed under the Apache License, Version 2.0 (the "License");
*  you may not use this file except in compliance with the License.
*  You may obtain a copy of the License at
*
*  http://www.apache.org/licenses/LICENSE-2.0
*
*  Unless required by applicable law or agreed to in writing, software
*  distributed under the License is distributed on an "AS IS" BASIS,
*  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
*  See the License for the specific language governing permissions and
*  limitations under the License.
*/
package me.zhengjie.modules.dm.envmonitor.historywarn.rest;

import me.zhengjie.annotation.Log;
import me.zhengjie.modules.dm.envmonitor.historywarn.domain.DmEnvHistoryWarn;
import me.zhengjie.modules.dm.envmonitor.historywarn.service.DmEnvHistoryWarnService;
import me.zhengjie.modules.dm.envmonitor.historywarn.service.dto.DmEnvHistoryWarnQueryCriteria;
import org.springframework.data.domain.Pageable;
import lombok.RequiredArgsConstructor;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import io.swagger.annotations.*;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;

/**
* @website https://el-admin.vip
* @author lr
* @date 2022-05-19
**/
@RestController
@RequiredArgsConstructor
@Api(tags = "历史告警管理")
@RequestMapping("/api/dmEnvHistoryWarn")
public class DmEnvHistoryWarnController {

    private final DmEnvHistoryWarnService dmEnvHistoryWarnService;

    @Log("导出数据")
    @ApiOperation("导出数据")
    @GetMapping(value = "/download")
    @PreAuthorize("@el.check('dmEnvHistoryWarn:list')")
    public void download(HttpServletResponse response, DmEnvHistoryWarnQueryCriteria criteria) throws IOException {
        dmEnvHistoryWarnService.download(dmEnvHistoryWarnService.queryAll(criteria), response);
    }

    @GetMapping
    @Log("查询历史告警")
    @ApiOperation("查询历史告警")
    @PreAuthorize("@el.check('dmEnvHistoryWarn:list')")
    public ResponseEntity<Object> query(DmEnvHistoryWarnQueryCriteria criteria, Pageable pageable){
        return new ResponseEntity<>(dmEnvHistoryWarnService.queryAll(criteria,pageable),HttpStatus.OK);
    }

    @PostMapping
    @Log("新增历史告警")
    @ApiOperation("新增历史告警")
    @PreAuthorize("@el.check('dmEnvHistoryWarn:add')")
    public ResponseEntity<Object> create(@Validated @RequestBody DmEnvHistoryWarn resources){
        return new ResponseEntity<>(dmEnvHistoryWarnService.create(resources),HttpStatus.CREATED);
    }

    @PutMapping
    @Log("修改历史告警")
    @ApiOperation("修改历史告警")
    @PreAuthorize("@el.check('dmEnvHistoryWarn:edit')")
    public ResponseEntity<Object> update(@Validated @RequestBody DmEnvHistoryWarn resources){
        dmEnvHistoryWarnService.update(resources);
        return new ResponseEntity<>(HttpStatus.NO_CONTENT);
    }

    @Log("删除历史告警")
    @ApiOperation("删除历史告警")
    @PreAuthorize("@el.check('dmEnvHistoryWarn:del')")
    @DeleteMapping
    public ResponseEntity<Object> delete(@RequestBody Long[] ids) {
        dmEnvHistoryWarnService.deleteAll(ids);
        return new ResponseEntity<>(HttpStatus.OK);
    }
}