/*
*  Copyright 2019-2020 Zheng Jie
*
*  Licensed under the Apache License, Version 2.0 (the "License");
*  you may not use this file except in compliance with the License.
*  You may obtain a copy of the License at
*
*  http://www.apache.org/licenses/LICENSE-2.0
*
*  Unless required by applicable law or agreed to in writing, software
*  distributed under the License is distributed on an "AS IS" BASIS,
*  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
*  See the License for the specific language governing permissions and
*  limitations under the License.
*/
package me.zhengjie.modules.dm.envmonitor.historywarnconfig.service.impl;

import me.zhengjie.modules.dm.envmonitor.historywarnconfig.domain.DmEnvHistoryWarnConfig;
import me.zhengjie.utils.ValidationUtil;
import me.zhengjie.utils.FileUtil;
import lombok.RequiredArgsConstructor;
import me.zhengjie.modules.dm.envmonitor.historywarnconfig.repository.DmEnvHistoryWarnConfigRepository;
import me.zhengjie.modules.dm.envmonitor.historywarnconfig.service.DmEnvHistoryWarnConfigService;
import me.zhengjie.modules.dm.envmonitor.historywarnconfig.service.dto.DmEnvHistoryWarnConfigDto;
import me.zhengjie.modules.dm.envmonitor.historywarnconfig.service.dto.DmEnvHistoryWarnConfigQueryCriteria;
import me.zhengjie.modules.dm.envmonitor.historywarnconfig.service.mapstruct.DmEnvHistoryWarnConfigMapper;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import me.zhengjie.utils.PageUtil;
import me.zhengjie.utils.QueryHelp;
import java.util.List;
import java.util.Map;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import java.util.ArrayList;
import java.util.LinkedHashMap;

/**
* @website https://el-admin.vip
* @description 服务实现
* @author lr
* @date 2022-05-19
**/
@Service
@RequiredArgsConstructor
public class DmEnvHistoryWarnConfigServiceImpl implements DmEnvHistoryWarnConfigService {

    private final DmEnvHistoryWarnConfigRepository dmEnvHistoryWarnConfigRepository;
    private final DmEnvHistoryWarnConfigMapper dmEnvHistoryWarnConfigMapper;

    @Override
    public Map<String,Object> queryAll(DmEnvHistoryWarnConfigQueryCriteria criteria, Pageable pageable){
        Page<DmEnvHistoryWarnConfig> page = dmEnvHistoryWarnConfigRepository.findAll((root, criteriaQuery, criteriaBuilder) -> QueryHelp.getPredicate(root,criteria,criteriaBuilder),pageable);
        return PageUtil.toPage(page.map(dmEnvHistoryWarnConfigMapper::toDto));
    }

    @Override
    public List<DmEnvHistoryWarnConfigDto> queryAll(DmEnvHistoryWarnConfigQueryCriteria criteria){
        return dmEnvHistoryWarnConfigMapper.toDto(dmEnvHistoryWarnConfigRepository.findAll((root, criteriaQuery, criteriaBuilder) -> QueryHelp.getPredicate(root,criteria,criteriaBuilder)));
    }

    @Override
    @Transactional
    public DmEnvHistoryWarnConfigDto findById(Long id) {
        DmEnvHistoryWarnConfig dmEnvHistoryWarnConfig = dmEnvHistoryWarnConfigRepository.findById(id).orElseGet(DmEnvHistoryWarnConfig::new);
        ValidationUtil.isNull(dmEnvHistoryWarnConfig.getId(),"DmEnvHistoryWarnConfig","id",id);
        return dmEnvHistoryWarnConfigMapper.toDto(dmEnvHistoryWarnConfig);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public DmEnvHistoryWarnConfigDto create(DmEnvHistoryWarnConfig resources) {
        return dmEnvHistoryWarnConfigMapper.toDto(dmEnvHistoryWarnConfigRepository.save(resources));
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public void update(DmEnvHistoryWarnConfig resources) {
        DmEnvHistoryWarnConfig dmEnvHistoryWarnConfig = dmEnvHistoryWarnConfigRepository.findById(resources.getId()).orElseGet(DmEnvHistoryWarnConfig::new);
        ValidationUtil.isNull( dmEnvHistoryWarnConfig.getId(),"DmEnvHistoryWarnConfig","id",resources.getId());
        dmEnvHistoryWarnConfig.copy(resources);
        dmEnvHistoryWarnConfigRepository.save(dmEnvHistoryWarnConfig);
    }

    @Override
    public void deleteAll(Long[] ids) {
        for (Long id : ids) {
            dmEnvHistoryWarnConfigRepository.deleteById(id);
        }
    }

    @Override
    public void download(List<DmEnvHistoryWarnConfigDto> all, HttpServletResponse response) throws IOException {
        List<Map<String, Object>> list = new ArrayList<>();
        for (DmEnvHistoryWarnConfigDto dmEnvHistoryWarnConfig : all) {
            Map<String,Object> map = new LinkedHashMap<>();
            map.put("数据项", dmEnvHistoryWarnConfig.getDataItem());
            map.put("告警值", dmEnvHistoryWarnConfig.getWarnValue());
            map.put("创建人", dmEnvHistoryWarnConfig.getCreateBy());
            map.put("更新人", dmEnvHistoryWarnConfig.getUpdateBy());
            map.put("创建时间", dmEnvHistoryWarnConfig.getCreateTime());
            map.put("更新时间", dmEnvHistoryWarnConfig.getUpdateTime());
            list.add(map);
        }
        FileUtil.downloadExcel(list, response);
    }
}