/*
*  Copyright 2019-2020 Zheng Jie
*
*  Licensed under the Apache License, Version 2.0 (the "License");
*  you may not use this file except in compliance with the License.
*  You may obtain a copy of the License at
*
*  http://www.apache.org/licenses/LICENSE-2.0
*
*  Unless required by applicable law or agreed to in writing, software
*  distributed under the License is distributed on an "AS IS" BASIS,
*  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
*  See the License for the specific language governing permissions and
*  limitations under the License.
*/
package me.zhengjie.modules.dm.envmonitor.icdevicenew.rest;

import me.zhengjie.annotation.Log;
import me.zhengjie.modules.dm.envmonitor.icdevicenew.domain.DmEnvIcDeciveNew;
import me.zhengjie.modules.dm.envmonitor.icdevicenew.service.DmEnvIcDeciveNewService;
import me.zhengjie.modules.dm.envmonitor.icdevicenew.service.dto.DmEnvIcDeciveNewQueryCriteria;
import org.springframework.data.domain.Pageable;
import lombok.RequiredArgsConstructor;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import io.swagger.annotations.*;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;

/**
* @website https://el-admin.vip
* @author wanglongda
* @date 2022-05-12
**/
@RestController
@RequiredArgsConstructor
@Api(tags = "通信设备管理")
@RequestMapping("/api/dmEnvIcDeciveNew")
public class DmEnvIcDeciveNewController {

    private final DmEnvIcDeciveNewService dmEnvIcDeciveNewService;

    @Log("导出数据")
    @ApiOperation("导出数据")
    @GetMapping(value = "/download")
    @PreAuthorize("@el.check('dmEnvIcDeciveNew:list')")
    public void download(HttpServletResponse response, DmEnvIcDeciveNewQueryCriteria criteria) throws IOException {
        dmEnvIcDeciveNewService.download(dmEnvIcDeciveNewService.queryAll(criteria), response);
    }

    @GetMapping
    @Log("查询通信设备")
    @ApiOperation("查询通信设备")
    @PreAuthorize("@el.check('dmEnvIcDeciveNew:list')")
    public ResponseEntity<Object> query(DmEnvIcDeciveNewQueryCriteria criteria, Pageable pageable){
        return new ResponseEntity<>(dmEnvIcDeciveNewService.queryAll(criteria,pageable),HttpStatus.OK);
    }

    @PostMapping
    @Log("新增通信设备")
    @ApiOperation("新增通信设备")
    @PreAuthorize("@el.check('dmEnvIcDeciveNew:add')")
    public ResponseEntity<Object> create(@Validated @RequestBody DmEnvIcDeciveNew resources){
        return new ResponseEntity<>(dmEnvIcDeciveNewService.create(resources),HttpStatus.CREATED);
    }

    @PutMapping
    @Log("修改通信设备")
    @ApiOperation("修改通信设备")
    @PreAuthorize("@el.check('dmEnvIcDeciveNew:edit')")
    public ResponseEntity<Object> update(@Validated @RequestBody DmEnvIcDeciveNew resources){
        dmEnvIcDeciveNewService.update(resources);
        return new ResponseEntity<>(HttpStatus.NO_CONTENT);
    }

    @Log("删除通信设备")
    @ApiOperation("删除通信设备")
    @PreAuthorize("@el.check('dmEnvIcDeciveNew:del')")
    @DeleteMapping
    public ResponseEntity<Object> delete(@RequestBody Long[] ids) {
        dmEnvIcDeciveNewService.deleteAll(ids);
        return new ResponseEntity<>(HttpStatus.OK);
    }
}