/*
*  Copyright 2019-2020 Zheng Jie
*
*  Licensed under the Apache License, Version 2.0 (the "License");
*  you may not use this file except in compliance with the License.
*  You may obtain a copy of the License at
*
*  http://www.apache.org/licenses/LICENSE-2.0
*
*  Unless required by applicable law or agreed to in writing, software
*  distributed under the License is distributed on an "AS IS" BASIS,
*  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
*  See the License for the specific language governing permissions and
*  limitations under the License.
*/
package me.zhengjie.modules.dm.envmonitor.monitorobject.rest;

import me.zhengjie.annotation.Log;
import me.zhengjie.modules.dm.envmonitor.monitorobject.domain.DmEnvMonitorObject;
import me.zhengjie.modules.dm.envmonitor.monitorobject.service.DmEnvMonitorObjectService;
import me.zhengjie.modules.dm.envmonitor.monitorobject.service.dto.DmEnvMonitorObjectQueryCriteria;
import org.springframework.data.domain.Pageable;
import lombok.RequiredArgsConstructor;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import io.swagger.annotations.*;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;

/**
* @website https://el-admin.vip
* @author lr
* @date 2022-05-19
**/
@RestController
@RequiredArgsConstructor
@Api(tags = "监控对象管理管理")
@RequestMapping("/api/dmEnvMonitorObject")
public class DmEnvMonitorObjectController {

    private final DmEnvMonitorObjectService dmEnvMonitorObjectService;

    @Log("导出数据")
    @ApiOperation("导出数据")
    @GetMapping(value = "/download")
    @PreAuthorize("@el.check('dmEnvMonitorObject:list')")
    public void download(HttpServletResponse response, DmEnvMonitorObjectQueryCriteria criteria) throws IOException {
        dmEnvMonitorObjectService.download(dmEnvMonitorObjectService.queryAll(criteria), response);
    }

    @GetMapping
    @Log("查询监控对象管理")
    @ApiOperation("查询监控对象管理")
    @PreAuthorize("@el.check('dmEnvMonitorObject:list')")
    public ResponseEntity<Object> query(DmEnvMonitorObjectQueryCriteria criteria, Pageable pageable){
        return new ResponseEntity<>(dmEnvMonitorObjectService.queryAll(criteria,pageable),HttpStatus.OK);
    }

    @PostMapping
    @Log("新增监控对象管理")
    @ApiOperation("新增监控对象管理")
    @PreAuthorize("@el.check('dmEnvMonitorObject:add')")
    public ResponseEntity<Object> create(@Validated @RequestBody DmEnvMonitorObject resources){
        return new ResponseEntity<>(dmEnvMonitorObjectService.create(resources),HttpStatus.CREATED);
    }

    @PutMapping
    @Log("修改监控对象管理")
    @ApiOperation("修改监控对象管理")
    @PreAuthorize("@el.check('dmEnvMonitorObject:edit')")
    public ResponseEntity<Object> update(@Validated @RequestBody DmEnvMonitorObject resources){
        dmEnvMonitorObjectService.update(resources);
        return new ResponseEntity<>(HttpStatus.NO_CONTENT);
    }

    @Log("删除监控对象管理")
    @ApiOperation("删除监控对象管理")
    @PreAuthorize("@el.check('dmEnvMonitorObject:del')")
    @DeleteMapping
    public ResponseEntity<Object> delete(@RequestBody Long[] ids) {
        dmEnvMonitorObjectService.deleteAll(ids);
        return new ResponseEntity<>(HttpStatus.OK);
    }
}