/*
*  Copyright 2019-2020 Zheng Jie
*
*  Licensed under the Apache License, Version 2.0 (the "License");
*  you may not use this file except in compliance with the License.
*  You may obtain a copy of the License at
*
*  http://www.apache.org/licenses/LICENSE-2.0
*
*  Unless required by applicable law or agreed to in writing, software
*  distributed under the License is distributed on an "AS IS" BASIS,
*  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
*  See the License for the specific language governing permissions and
*  limitations under the License.
*/
package me.zhengjie.modules.dm.envmonitor.peptdevice.rest;

import me.zhengjie.annotation.Log;
import me.zhengjie.modules.dm.envmonitor.peptdevice.domain.DmEnvPeptDevice;
import me.zhengjie.modules.dm.envmonitor.peptdevice.service.DmEnvPeptDeviceService;
import me.zhengjie.modules.dm.envmonitor.peptdevice.service.dto.DmEnvPeptDeviceQueryCriteria;
import org.springframework.data.domain.Pageable;
import lombok.RequiredArgsConstructor;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import io.swagger.annotations.*;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;

/**
* @website https://el-admin.vip
* @author shuai.huang
* @date 2021-03-30
**/
@RestController
@RequiredArgsConstructor
@Api(tags = "感知设备管理")
@RequestMapping("/api/dmEnvPeptDevice")
public class DmEnvPeptDeviceController {

    private final DmEnvPeptDeviceService dmEnvPeptDeviceService;

    @Log("导出数据")
    @ApiOperation("导出数据")
    @GetMapping(value = "/download")
    @PreAuthorize("@el.check('dmEnvPeptDevice:list')")
    public void download(HttpServletResponse response, DmEnvPeptDeviceQueryCriteria criteria) throws IOException {
        dmEnvPeptDeviceService.download(dmEnvPeptDeviceService.queryAll(criteria), response);
    }

    @GetMapping
    @Log("查询感知设备")
    @ApiOperation("查询感知设备")
    @PreAuthorize("@el.check('dmEnvPeptDevice:list')")
    public ResponseEntity<Object> query(DmEnvPeptDeviceQueryCriteria criteria, Pageable pageable){
        return new ResponseEntity<>(dmEnvPeptDeviceService.queryAll(criteria,pageable),HttpStatus.OK);
    }

    @PostMapping
    @Log("新增感知设备")
    @ApiOperation("新增感知设备")
    @PreAuthorize("@el.check('dmEnvPeptDevice:add')")
    public ResponseEntity<Object> create(@Validated @RequestBody DmEnvPeptDevice resources){
        return new ResponseEntity<>(dmEnvPeptDeviceService.create(resources),HttpStatus.CREATED);
    }

    @PutMapping
    @Log("修改感知设备")
    @ApiOperation("修改感知设备")
    @PreAuthorize("@el.check('dmEnvPeptDevice:edit')")
    public ResponseEntity<Object> update(@Validated @RequestBody DmEnvPeptDevice resources){
        dmEnvPeptDeviceService.update(resources);
        return new ResponseEntity<>(HttpStatus.NO_CONTENT);
    }

    @Log("删除感知设备")
    @ApiOperation("删除感知设备")
    @PreAuthorize("@el.check('dmEnvPeptDevice:del')")
    @DeleteMapping
    public ResponseEntity<Object> delete(@RequestBody Long[] ids) {
        dmEnvPeptDeviceService.deleteAll(ids);
        return new ResponseEntity<>(HttpStatus.OK);
    }
}