/*
*  Copyright 2019-2020 Zheng Jie
*
*  Licensed under the Apache License, Version 2.0 (the "License");
*  you may not use this file except in compliance with the License.
*  You may obtain a copy of the License at
*
*  http://www.apache.org/licenses/LICENSE-2.0
*
*  Unless required by applicable law or agreed to in writing, software
*  distributed under the License is distributed on an "AS IS" BASIS,
*  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
*  See the License for the specific language governing permissions and
*  limitations under the License.
*/
package me.zhengjie.modules.dm.floor.rest;

import me.zhengjie.annotation.Log;
import me.zhengjie.modules.dm.floor.domain.DmFloor;
import me.zhengjie.modules.dm.floor.service.DmFloorService;
import me.zhengjie.modules.dm.floor.service.dto.DmFloorQueryCriteria;
import org.springframework.data.domain.Pageable;
import lombok.RequiredArgsConstructor;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import io.swagger.annotations.*;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;

/**
* @website https://el-admin.vip
* @author shiguangji
* @date 2021-03-11
**/
@RestController
@RequiredArgsConstructor
@Api(tags = "楼层管理")
@RequestMapping("/api/dmFloor")
public class DmFloorController {

    private final DmFloorService dmFloorService;

    @Log("导出数据")
    @ApiOperation("导出数据")
    @GetMapping(value = "/download")
    @PreAuthorize("@el.check('dmFloor:list')")
    public void download(HttpServletResponse response, DmFloorQueryCriteria criteria) throws IOException {
        dmFloorService.download(dmFloorService.queryAll(criteria), response);
    }

    @GetMapping
    @Log("查询楼层")
    @ApiOperation("查询楼层")
    @PreAuthorize("@el.check('dmFloor:list')")
    public ResponseEntity<Object> query(DmFloorQueryCriteria criteria, Pageable pageable){
        return new ResponseEntity<>(dmFloorService.queryAll(criteria,pageable),HttpStatus.OK);
    }

    @PostMapping
    @Log("新增楼层")
    @ApiOperation("新增楼层")
    @PreAuthorize("@el.check('dmFloor:add')")
    public ResponseEntity<Object> create(@Validated @RequestBody DmFloor resources){
        return new ResponseEntity<>(dmFloorService.create(resources),HttpStatus.CREATED);
    }

    @PutMapping
    @Log("修改楼层")
    @ApiOperation("修改楼层")
    @PreAuthorize("@el.check('dmFloor:edit')")
    public ResponseEntity<Object> update(@Validated @RequestBody DmFloor resources){
        dmFloorService.update(resources);
        return new ResponseEntity<>(HttpStatus.NO_CONTENT);
    }

    @Log("删除楼层")
    @ApiOperation("删除楼层")
    @PreAuthorize("@el.check('dmFloor:del')")
    @DeleteMapping
    public ResponseEntity<Object> delete(@RequestBody Long[] ids) {
        dmFloorService.deleteAll(ids);
        return new ResponseEntity<>(HttpStatus.OK);
    }
}